from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.copy_dataset_request_metadata import CopyDatasetRequestMetadata
from ..models.copy_dataset_request_tags import CopyDatasetRequestTags
from ..types import UNSET, Unset

T = TypeVar("T", bound="CopyDatasetRequest")


@attr.s(auto_attribs=True)
class CopyDatasetRequest:
    """Request body for copy dataset operation"""

    name: str
    tags: Union[CopyDatasetRequestTags, Unset] = UNSET
    metadata: Union[CopyDatasetRequestMetadata, Unset] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        tags: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.tags, Unset):
            tags = self.tags.to_dict()

        metadata: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.metadata, Unset):
            metadata = self.metadata.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "name": name,
            }
        )
        if tags is not UNSET:
            field_dict["tags"] = tags
        if metadata is not UNSET:
            field_dict["metadata"] = metadata

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("name")

        tags: Union[CopyDatasetRequestTags, Unset] = UNSET
        _tags = d.pop("tags", UNSET)
        if not isinstance(_tags, Unset):
            tags = CopyDatasetRequestTags.from_dict(_tags)

        metadata: Union[CopyDatasetRequestMetadata, Unset] = UNSET
        _metadata = d.pop("metadata", UNSET)
        if not isinstance(_metadata, Unset):
            metadata = CopyDatasetRequestMetadata.from_dict(_metadata)

        copy_dataset_request = cls(
            name=name,
            tags=tags,
            metadata=metadata,
        )

        copy_dataset_request.additional_properties = d
        return copy_dataset_request

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
